# Extracts useful data from urls (domain, subdomains, top level ...)

```python
# Tested with:
# Python 3.9.13
# Windows 10

pip install url-analyzer 

from url_analyzer import get_all_links_from_url, get_url_df, get_all_links_from_html
# Update 2023/01/08: get_all_links_from_html 
df = get_all_links_from_html(url="https://github.com/hansalemaos/getevent_sendevent", htmlcode='<html>...</html>') # url necessary for relative links 


df = get_all_links_from_url(url="https://github.com/hansalemaos/getevent_sendevent")

r"""
   aa_scheme                          aa_netloc                                                                                                                        aa_path            aa_query                                                                      aa_fragment aa_filetype  aa_is_relative                                                                                                                                                aa_url_noquery                                                                                                                                                  aa_url_query aa_toplevel            aa_subdomain_domain          aa_domain aa_subdomains                                                                                                                                           aa_unquoted_noquery                                                                                                                                      aa_folder_on_hdd         aa_domain_w_tl                                        aa_original
0      https                         github.com                                                                                                                                                                                                                                                            True                                                                                                             https://github.com/hansalemaos/getevent_sendevent                                                                                                                                            https://github.com        .com                         github             github                                                                                                                           https://github.com/hansalemaos/getevent_sendevent                                                                                                             github.com\hansalemaos\getevent_sendevent             github.com  https://github.com/hansalemaos/getevent_sendevent
1      https            github.githubassets.com   /assets/vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_mini-th-85225b-d5c5eb0b8bb2.js                                                                                                              .js           False   https://github.githubassets.com/assets/vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_mini-th-85225b-d5c5eb0b8bb2.js   https://github.githubassets.com/assets/vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_mini-th-85225b-d5c5eb0b8bb2.js        .com            github.githubassets       githubassets        github   https://github.githubassets.com/assets/vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_mini-th-85225b-d5c5eb0b8bb2.js   github.githubassets.com\assets\vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_mini-th-85225b-d5c5eb0b8bb2.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
2      https                         github.com                                                                                                              /features/copilot                                                                                                                             True                                                                                                                           https://github.com/features/copilot                                                                                                                           https://github.com/features/copilot        .com                         github             github                                                                                                                                         https://github.com/features/copilot                                                                                                                           github.com\features\copilot             github.com  https://github.com/hansalemaos/getevent_sendevent
3      https                         github.com                                                                                                                    /topics/bot                                                                                                                             True                                                                                                                                 https://github.com/topics/bot                                                                                                                                 https://github.com/topics/bot        .com                         github             github                                                                                                                                               https://github.com/topics/bot                                                                                                                                 github.com\topics\bot             github.com  https://github.com/hansalemaos/getevent_sendevent
4      https            github.githubassets.com                                                                                               /assets/sessions-ef3a905b759f.js                                                                                                              .js           False                                                                                               https://github.githubassets.com/assets/sessions-ef3a905b759f.js                                                                                               https://github.githubassets.com/assets/sessions-ef3a905b759f.js        .com            github.githubassets       githubassets        github                                                                                               https://github.githubassets.com/assets/sessions-ef3a905b759f.js                                                                                               github.githubassets.com\assets\sessions-ef3a905b759f.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
5       http                         www.w3.org                                                                                                                      /2000/svg                                                                                                                            False                                                                                                                                    http://www.w3.org/2000/svg                                                                                                                                    http://www.w3.org/2000/svg        .org                             w3                 w3                                                                                                                                                  http://www.w3.org/2000/svg                                                                                                                                   www.w3.org\2000\svg                 w3.org  https://github.com/hansalemaos/getevent_sendevent
6      https            github.githubassets.com   /assets/vendors-node_modules_github_paste-markdown_dist_index_esm_js-node_modules_github_quote-select-f57862-d5fdfac7e5dd.js                                                                                                              .js           False   https://github.githubassets.com/assets/vendors-node_modules_github_paste-markdown_dist_index_esm_js-node_modules_github_quote-select-f57862-d5fdfac7e5dd.js   https://github.githubassets.com/assets/vendors-node_modules_github_paste-markdown_dist_index_esm_js-node_modules_github_quote-select-f57862-d5fdfac7e5dd.js        .com            github.githubassets       githubassets        github   https://github.githubassets.com/assets/vendors-node_modules_github_paste-markdown_dist_index_esm_js-node_modules_github_quote-select-f57862-d5fdfac7e5dd.js   github.githubassets.com\assets\vendors-node_modules_github_paste-markdown_dist_index_esm_js-node_modules_github_quote-select-f57862-d5fdfac7e5dd.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
7      https         opengraph.githubassets.com                               /dd66aca2cf93ab4caf05ca7ea0d973dc908721e75d031d82117e80f2c2353c26/hansalemaos/getevent_sendevent                                                                                                                            False                            https://opengraph.githubassets.com/dd66aca2cf93ab4caf05ca7ea0d973dc908721e75d031d82117e80f2c2353c26/hansalemaos/getevent_sendevent                            https://opengraph.githubassets.com/dd66aca2cf93ab4caf05ca7ea0d973dc908721e75d031d82117e80f2c2353c26/hansalemaos/getevent_sendevent        .com         opengraph.githubassets       githubassets     opengraph                            https://opengraph.githubassets.com/dd66aca2cf93ab4caf05ca7ea0d973dc908721e75d031d82117e80f2c2353c26/hansalemaos/getevent_sendevent                            opengraph.githubassets.com\dd66aca2cf93ab4caf05ca7ea0d973dc908721e75d031d82117e80f2c2353c26\hansalemaos\getevent_sendevent       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
8      https                         github.com                                                                                                              /solutions/ci-cd/                                                                                                                             True                                                                                                                           https://github.com/solutions/ci-cd/                                                                                                                           https://github.com/solutions/ci-cd/        .com                         github             github                                                                                                                                         https://github.com/solutions/ci-cd/                                                                                                                            github.com\solutions\ci-cd             github.com  https://github.com/hansalemaos/getevent_sendevent
9      https                services.github.com                                                                                                                                                                                                                                                           False                                                                                                                                   https://services.github.com                                                                                                                                   https://services.github.com        .com                services.github             github      services                                                                                                                                   https://services.github.com                                                                                                                                   services.github.com             github.com  https://github.com/hansalemaos/getevent_sendevent
10     https                         github.com                                                                                        /hansalemaos/getevent_sendevent/actions                                                                                                                             True                                                                                                     https://github.com/hansalemaos/getevent_sendevent/actions                                                                                                     https://github.com/hansalemaos/getevent_sendevent/actions        .com                         github             github                                                                                                                   https://github.com/hansalemaos/getevent_sendevent/actions                                                                                                     github.com\hansalemaos\getevent_sendevent\actions             github.com  https://github.com/hansalemaos/getevent_sendevent
11     https                         github.com                                                                                                                        /readme                                                                                                                             True                                                                                                                                     https://github.com/readme                                                                                                                                     https://github.com/readme        .com                         github             github                                                                                                                                                   https://github.com/readme                                                                                                                                     github.com\readme             github.com  https://github.com/hansalemaos/getevent_sendevent
12     https            github.githubassets.com   /assets/vendors-node_modules_smoothscroll-polyfill_dist_smoothscroll_js-node_modules_stacktrace-parse-297da6-aaa32681a0b3.js                                                                                                              .js           False   https://github.githubassets.com/assets/vendors-node_modules_smoothscroll-polyfill_dist_smoothscroll_js-node_modules_stacktrace-parse-297da6-aaa32681a0b3.js   https://github.githubassets.com/assets/vendors-node_modules_smoothscroll-polyfill_dist_smoothscroll_js-node_modules_stacktrace-parse-297da6-aaa32681a0b3.js        .com            github.githubassets       githubassets        github   https://github.githubassets.com/assets/vendors-node_modules_smoothscroll-polyfill_dist_smoothscroll_js-node_modules_stacktrace-parse-297da6-aaa32681a0b3.js   github.githubassets.com\assets\vendors-node_modules_smoothscroll-polyfill_dist_smoothscroll_js-node_modules_stacktrace-parse-297da6-aaa32681a0b3.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
13     https            github.githubassets.com   /assets/vendors-node_modules_optimizely_optimizely-sdk_dist_optimizely_browser_es_min_js-node_modules-77839b-550a5f909f1b.js                                                                                                              .js           False   https://github.githubassets.com/assets/vendors-node_modules_optimizely_optimizely-sdk_dist_optimizely_browser_es_min_js-node_modules-77839b-550a5f909f1b.js   https://github.githubassets.com/assets/vendors-node_modules_optimizely_optimizely-sdk_dist_optimizely_browser_es_min_js-node_modules-77839b-550a5f909f1b.js        .com            github.githubassets       githubassets        github   https://github.githubassets.com/assets/vendors-node_modules_optimizely_optimizely-sdk_dist_optimizely_browser_es_min_js-node_modules-77839b-550a5f909f1b.js   github.githubassets.com\assets\vendors-node_modules_optimizely_optimizely-sdk_dist_optimizely_browser_es_min_js-node_modules-77839b-550a5f909f1b.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
14     https                           pypi.org                                                                                                    /project/getevent-sendevent                                                                                                                            False                                                                                                                   https://pypi.org/project/getevent-sendevent                                                                                                                   https://pypi.org/project/getevent-sendevent        .org                           pypi               pypi                                                                                                                                 https://pypi.org/project/getevent-sendevent                                                                                                                   pypi.org\project\getevent-sendevent               pypi.org  https://github.com/hansalemaos/getevent_sendevent
15     https                         github.com                                                                                          /hansalemaos/getevent_sendevent/pulls                                                                                                                             True                                                                                                       https://github.com/hansalemaos/getevent_sendevent/pulls                                                                                                       https://github.com/hansalemaos/getevent_sendevent/pulls        .com                         github             github                                                                                                                     https://github.com/hansalemaos/getevent_sendevent/pulls                                                                                                       github.com\hansalemaos\getevent_sendevent\pulls             github.com  https://github.com/hansalemaos/getevent_sendevent
16     https            github.githubassets.com                                                                                                /assets/github-762fdeac7c4d.css                                                                                                             .css           False                                                                                                https://github.githubassets.com/assets/github-762fdeac7c4d.css                                                                                                https://github.githubassets.com/assets/github-762fdeac7c4d.css        .com            github.githubassets       githubassets        github                                                                                                https://github.githubassets.com/assets/github-762fdeac7c4d.css                                                                                                github.githubassets.com\assets\github-762fdeac7c4d.css       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
17     https                         github.com                                                                              /hansalemaos/getevent_sendevent/blob/main/LICENSE                                                                                                                             True                                                                                           https://github.com/hansalemaos/getevent_sendevent/blob/main/LICENSE                                                                                           https://github.com/hansalemaos/getevent_sendevent/blob/main/LICENSE        .com                         github             github                                                                                                         https://github.com/hansalemaos/getevent_sendevent/blob/main/LICENSE                                                                                           github.com\hansalemaos\getevent_sendevent\blob\main\LICENSE             github.com  https://github.com/hansalemaos/getevent_sendevent
18     https  user-images.githubusercontent.com                                                                                                                              /                                                                                                                            False                                                                                                                    https://user-images.githubusercontent.com/                                                                                                                    https://user-images.githubusercontent.com/        .com  user-images.githubusercontent  githubusercontent   user-images                                                                                                                    https://user-images.githubusercontent.com/                                                                                                                     user-images.githubusercontent.com  githubusercontent.com  https://github.com/hansalemaos/getevent_sendevent
19     https                         github.com                                                                                                                                                                                                                             2nd-way                        True                                                                                                     https://github.com/hansalemaos/getevent_sendevent#2nd-way                                                                                                                                    https://github.com#2nd-way        .com                         github             github                                                                                                                   https://github.com/hansalemaos/getevent_sendevent#2nd-way                                                                                                     github.com\hansalemaos\getevent_sendevent#2nd-way             github.com  https://github.com/hansalemaos/getevent_sendevent
20     https            github.githubassets.com  /assets/vendors-node_modules_delegated-events_dist_index_js-node_modules_github_catalyst_lib_index_js-06ff531-596c6d852b03.js                                                                                                              .js           False  https://github.githubassets.com/assets/vendors-node_modules_delegated-events_dist_index_js-node_modules_github_catalyst_lib_index_js-06ff531-596c6d852b03.js  https://github.githubassets.com/assets/vendors-node_modules_delegated-events_dist_index_js-node_modules_github_catalyst_lib_index_js-06ff531-596c6d852b03.js        .com            github.githubassets       githubassets        github  https://github.githubassets.com/assets/vendors-node_modules_delegated-events_dist_index_js-node_modules_github_catalyst_lib_index_js-06ff531-596c6d852b03.js  github.githubassets.com\assets\vendors-node_modules_delegated-events_dist_index_js-node_modules_github_catalyst_lib_index_js-06ff531-596c6d852b03.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
21     https                         github.com                                                                                                                   /collections                                                                                                                             True                                                                                                                                https://github.com/collections                                                                                                                                https://github.com/collections        .com                         github             github                                                                                                                                              https://github.com/collections                                                                                                                                github.com\collections             github.com  https://github.com/hansalemaos/getevent_sendevent
22     https                         github.com                                                                                           /hansalemaos/getevent_sendevent/tags                                                                                                                             True                                                                                                        https://github.com/hansalemaos/getevent_sendevent/tags                                                                                                        https://github.com/hansalemaos/getevent_sendevent/tags        .com                         github             github                                                                                                                      https://github.com/hansalemaos/getevent_sendevent/tags                                                                                                        github.com\hansalemaos\getevent_sendevent\tags             github.com  https://github.com/hansalemaos/getevent_sendevent
23     https                         github.com                                                                            /hansalemaos/getevent_sendevent/blob/main/README.MD                                                                                                              .MD            True                                                                                         https://github.com/hansalemaos/getevent_sendevent/blob/main/README.MD                                                                                         https://github.com/hansalemaos/getevent_sendevent/blob/main/README.MD        .com                         github             github                                                                                                       https://github.com/hansalemaos/getevent_sendevent/blob/main/README.MD                                                                                         github.com\hansalemaos\getevent_sendevent\blob\main\README.MD             github.com  https://github.com/hansalemaos/getevent_sendevent
24     https            github.githubassets.com   /assets/app_assets_modules_github_hydro-analytics_ts-app_assets_modules_github_soft-nav_state_ts-ui_p-e465e4-4b5f869b18ef.js                                                                                                              .js           False   https://github.githubassets.com/assets/app_assets_modules_github_hydro-analytics_ts-app_assets_modules_github_soft-nav_state_ts-ui_p-e465e4-4b5f869b18ef.js   https://github.githubassets.com/assets/app_assets_modules_github_hydro-analytics_ts-app_assets_modules_github_soft-nav_state_ts-ui_p-e465e4-4b5f869b18ef.js        .com            github.githubassets       githubassets        github   https://github.githubassets.com/assets/app_assets_modules_github_hydro-analytics_ts-app_assets_modules_github_soft-nav_state_ts-ui_p-e465e4-4b5f869b18ef.js   github.githubassets.com\assets\app_assets_modules_github_hydro-analytics_ts-app_assets_modules_github_soft-nav_state_ts-ui_p-e465e4-4b5f869b18ef.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
25     https                         github.com                                                                                                                 /fluidicon.png                                                                                                             .png           False                                                                                                                              https://github.com/fluidicon.png                                                                                                                              https://github.com/fluidicon.png        .com                         github             github                                                                                                                                            https://github.com/fluidicon.png                                                                                                                              github.com\fluidicon.png             github.com  https://github.com/hansalemaos/getevent_sendevent
26     https            github.githubassets.com                                                                                                          /favicons/favicon.svg                                                                                                             .svg           False                                                                                                          https://github.githubassets.com/favicons/favicon.svg                                                                                                          https://github.githubassets.com/favicons/favicon.svg        .com            github.githubassets       githubassets        github                                                                                                          https://github.githubassets.com/favicons/favicon.svg                                                                                                          github.githubassets.com\favicons\favicon.svg       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
27     https                         github.com                                                                                                                        /topics                                                                                                                             True                                                                                                                                     https://github.com/topics                                                                                                                                     https://github.com/topics        .com                         github             github                                                                                                                                                   https://github.com/topics                                                                                                                                     github.com\topics             github.com  https://github.com/hansalemaos/getevent_sendevent
28     https            github.githubassets.com   /assets/vendors-node_modules_github_filter-input-element_dist_index_js-node_modules_github_remote-inp-d1569f-cac1c97bc6a5.js                                                                                                              .js           False   https://github.githubassets.com/assets/vendors-node_modules_github_filter-input-element_dist_index_js-node_modules_github_remote-inp-d1569f-cac1c97bc6a5.js   https://github.githubassets.com/assets/vendors-node_modules_github_filter-input-element_dist_index_js-node_modules_github_remote-inp-d1569f-cac1c97bc6a5.js        .com            github.githubassets       githubassets        github   https://github.githubassets.com/assets/vendors-node_modules_github_filter-input-element_dist_index_js-node_modules_github_remote-inp-d1569f-cac1c97bc6a5.js   github.githubassets.com\assets\vendors-node_modules_github_filter-input-element_dist_index_js-node_modules_github_remote-inp-d1569f-cac1c97bc6a5.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
29     https                         github.com                                                                                          /hansalemaos/getevent_sendevent/pulse                                                                                                                             True                                                                                                       https://github.com/hansalemaos/getevent_sendevent/pulse                                                                                                       https://github.com/hansalemaos/getevent_sendevent/pulse        .com                         github             github                                                                                                                     https://github.com/hansalemaos/getevent_sendevent/pulse                                                                                                       github.com\hansalemaos\getevent_sendevent\pulse             github.com  https://github.com/hansalemaos/getevent_sendevent
30     https                         github.com                                                                                                              /topics/sendevent                                                                                                                             True                                                                                                                           https://github.com/topics/sendevent                                                                                                                           https://github.com/topics/sendevent        .com                         github             github                                                                                                                                         https://github.com/topics/sendevent                                                                                                                           github.com\topics\sendevent             github.com  https://github.com/hansalemaos/getevent_sendevent
31     https               collector.github.com                                                                                                                /github/collect                                                                                                                            False                                                                                                                   https://collector.github.com/github/collect                                                                                                                   https://collector.github.com/github/collect        .com               collector.github             github     collector                                                                                                                   https://collector.github.com/github/collect                                                                                                                   collector.github.com\github\collect             github.com  https://github.com/hansalemaos/getevent_sendevent
32     https                         github.com                                                                                                                      /trending                                                                                                                             True                                                                                                                                   https://github.com/trending                                                                                                                                   https://github.com/trending        .com                         github             github                                                                                                                                                 https://github.com/trending                                                                                                                                   github.com\trending             github.com  https://github.com/hansalemaos/getevent_sendevent
33     https                         github.com                                                  /hansalemaos/getevent_sendevent/tree/7b2008e5315e79646e0257530ad0e6ee15e30db2                                                                                                                             True                                                               https://github.com/hansalemaos/getevent_sendevent/tree/7b2008e5315e79646e0257530ad0e6ee15e30db2                                                               https://github.com/hansalemaos/getevent_sendevent/tree/7b2008e5315e79646e0257530ad0e6ee15e30db2        .com                         github             github                                                                             https://github.com/hansalemaos/getevent_sendevent/tree/7b2008e5315e79646e0257530ad0e6ee15e30db2                                                               github.com\hansalemaos\getevent_sendevent\tree\7b2008e5315e79646e0257530ad0e6ee15e30db2             github.com  https://github.com/hansalemaos/getevent_sendevent
34     https            github.githubassets.com                                                                                           /assets/repositories-bae26b76f8fa.js                                                                                                              .js           False                                                                                           https://github.githubassets.com/assets/repositories-bae26b76f8fa.js                                                                                           https://github.githubassets.com/assets/repositories-bae26b76f8fa.js        .com            github.githubassets       githubassets        github                                                                                           https://github.githubassets.com/assets/repositories-bae26b76f8fa.js                                                                                           github.githubassets.com\assets\repositories-bae26b76f8fa.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
35     https                         github.com                                                                                                                   /hansalemaos                                                                                                                             True                                                                                                                                https://github.com/hansalemaos                                                                                                                                https://github.com/hansalemaos        .com                         github             github                                                                                                                                              https://github.com/hansalemaos                                                                                                                                github.com\hansalemaos             github.com  https://github.com/hansalemaos/getevent_sendevent
36     https                         github.com                                                                           /hansalemaos/screenshots/raw/main/bluestacksauto.png                                                                                                             .png           False                                                                                        https://github.com/hansalemaos/screenshots/raw/main/bluestacksauto.png                                                                                        https://github.com/hansalemaos/screenshots/raw/main/bluestacksauto.png        .com                         github             github                                                                                                      https://github.com/hansalemaos/screenshots/raw/main/bluestacksauto.png                                                                                        github.com\hansalemaos\screenshots\raw\main\bluestacksauto.png             github.com  https://github.com/hansalemaos/getevent_sendevent
37     https                         github.com                                                                                                                 /topics/python                                                                                                                             True                                                                                                                              https://github.com/topics/python                                                                                                                              https://github.com/topics/python        .com                         github             github                                                                                                                                            https://github.com/topics/python                                                                                                                              github.com\topics\python             github.com  https://github.com/hansalemaos/getevent_sendevent
38     https            github.githubassets.com                                                                                              /assets/code-menu-3f4394522bb9.js                                                                                                              .js           False                                                                                              https://github.githubassets.com/assets/code-menu-3f4394522bb9.js                                                                                              https://github.githubassets.com/assets/code-menu-3f4394522bb9.js        .com            github.githubassets       githubassets        github                                                                                              https://github.githubassets.com/assets/code-menu-3f4394522bb9.js                                                                                              github.githubassets.com\assets\code-menu-3f4394522bb9.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
39     https                         github.com                                                                                                                                                                                                                            features                        True                                                                                                    https://github.com/hansalemaos/getevent_sendevent#features                                                                                                                                   https://github.com#features        .com                         github             github                                                                                                                  https://github.com/hansalemaos/getevent_sendevent#features                                                                                                    github.com\hansalemaos\getevent_sendevent#features             github.com  https://github.com/hansalemaos/getevent_sendevent
40     https            github.githubassets.com   /assets/vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_text-ex-3415a8-daf4603c6e6b.js                                                                                                              .js           False   https://github.githubassets.com/assets/vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_text-ex-3415a8-daf4603c6e6b.js   https://github.githubassets.com/assets/vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_text-ex-3415a8-daf4603c6e6b.js        .com            github.githubassets       githubassets        github   https://github.githubassets.com/assets/vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_text-ex-3415a8-daf4603c6e6b.js   github.githubassets.com\assets\vendors-node_modules_github_file-attachment-element_dist_index_js-node_modules_github_text-ex-3415a8-daf4603c6e6b.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
41     https            github.githubassets.com                                                                                   /assets/notifications-global-869bd2ddc368.js                                                                                                              .js           False                                                                                   https://github.githubassets.com/assets/notifications-global-869bd2ddc368.js                                                                                   https://github.githubassets.com/assets/notifications-global-869bd2ddc368.js        .com            github.githubassets       githubassets        github                                                                                   https://github.githubassets.com/assets/notifications-global-869bd2ddc368.js                                                                                   github.githubassets.com\assets\notifications-global-869bd2ddc368.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
42     https                         github.com                                                                                                                      /features                                                                                                                             True                                                                                                                                   https://github.com/features                                                                                                                                   https://github.com/features        .com                         github             github                                                                                                                                                 https://github.com/features                                                                                                                                   github.com\features             github.com  https://github.com/hansalemaos/getevent_sendevent
43     https                     api.github.com                                                                                                        /_private/browser/stats                                                                                                                            False                                                                                                                 https://api.github.com/_private/browser/stats                                                                                                                 https://api.github.com/_private/browser/stats        .com                     api.github             github           api                                                                                                                 https://api.github.com/_private/browser/stats                                                                                                                 api.github.com\_private\browser\stats             github.com  https://github.com/hansalemaos/getevent_sendevent
44     https                         github.com                                                                                     /hansalemaos/getevent_sendevent/stargazers                                                                                                                             True                                                                                                  https://github.com/hansalemaos/getevent_sendevent/stargazers                                                                                                  https://github.com/hansalemaos/getevent_sendevent/stargazers        .com                         github             github                                                                                                                https://github.com/hansalemaos/getevent_sendevent/stargazers                                                                                                  github.com\hansalemaos\getevent_sendevent\stargazers             github.com  https://github.com/hansalemaos/getevent_sendevent
45     https            github.githubassets.com   /assets/vendors-node_modules_github_remote-form_dist_index_js-node_modules_delegated-events_dist_inde-70450e-bdbaf1c3071b.js                                                                                                              .js           False   https://github.githubassets.com/assets/vendors-node_modules_github_remote-form_dist_index_js-node_modules_delegated-events_dist_inde-70450e-bdbaf1c3071b.js   https://github.githubassets.com/assets/vendors-node_modules_github_remote-form_dist_index_js-node_modules_delegated-events_dist_inde-70450e-bdbaf1c3071b.js        .com            github.githubassets       githubassets        github   https://github.githubassets.com/assets/vendors-node_modules_github_remote-form_dist_index_js-node_modules_delegated-events_dist_inde-70450e-bdbaf1c3071b.js   github.githubassets.com\assets\vendors-node_modules_github_remote-form_dist_index_js-node_modules_delegated-events_dist_inde-70450e-bdbaf1c3071b.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
46     https                        github.blog                                                                                                                                                                                                                                                           False                                                                                                                                           https://github.blog                                                                                                                                           https://github.blog       .blog                         github             github                                                                                                                                                         https://github.blog                                                                                                                                           github.blog            github.blog  https://github.com/hansalemaos/getevent_sendevent
47     https                         github.com                                                                                                               /features/issues                                                                                                                             True                                                                                                                            https://github.com/features/issues                                                                                                                            https://github.com/features/issues        .com                         github             github                                                                                                                                          https://github.com/features/issues                                                                                                                            github.com\features\issues             github.com  https://github.com/hansalemaos/getevent_sendevent
48     https                         github.com                                                                                                                         /about                                                                                                                            False                                                                                                                                      https://github.com/about                                                                                                                                      https://github.com/about        .com                         github             github                                                                                                                                                    https://github.com/about                                                                                                                                      github.com\about             github.com  https://github.com/hansalemaos/getevent_sendevent
49     https                     api.github.com                                                                                                       /_private/browser/errors                                                                                                                            False                                                                                                                https://api.github.com/_private/browser/errors                                                                                                                https://api.github.com/_private/browser/errors        .com                     api.github             github           api                                                                                                                https://api.github.com/_private/browser/errors                                                                                                                api.github.com\_private\browser\errors             github.com  https://github.com/hansalemaos/getevent_sendevent
50     https                         github.com                                                                          /hansalemaos/getevent_sendevent/overview_actions/main                                                                                                                             True                                                                                       https://github.com/hansalemaos/getevent_sendevent/overview_actions/main                                                                                       https://github.com/hansalemaos/getevent_sendevent/overview_actions/main        .com                         github             github                                                                                                     https://github.com/hansalemaos/getevent_sendevent/overview_actions/main                                                                                       github.com\hansalemaos\getevent_sendevent\overview_actions\main             github.com  https://github.com/hansalemaos/getevent_sendevent
51     https                developer.apple.com                                                                                                                        /xcode/                                                                                                                            False                                                                                                                            https://developer.apple.com/xcode/                                                                                                                            https://developer.apple.com/xcode/        .com                developer.apple              apple     developer                                                                                                                            https://developer.apple.com/xcode/                                                                                                                             developer.apple.com\xcode              apple.com  https://github.com/hansalemaos/getevent_sendevent
52     https                         github.com                                                                                                                       /pricing                                                                                                                             True                                                                                                                                    https://github.com/pricing                                                                                                                                    https://github.com/pricing        .com                         github             github                                                                                                                                                  https://github.com/pricing                                                                                                                                    github.com\pricing             github.com  https://github.com/hansalemaos/getevent_sendevent
53     https                         github.com                                                                                                             /features/packages                                                                                                                             True                                                                                                                          https://github.com/features/packages                                                                                                                          https://github.com/features/packages        .com                         github             github                                                                                                                                        https://github.com/features/packages                                                                                                                          github.com\features\packages             github.com  https://github.com/hansalemaos/getevent_sendevent
54     https                         github.com                                                                                                                    /enterprise                                                                                                                             True                                                                                                                                 https://github.com/enterprise                                                                                                                                 https://github.com/enterprise        .com                         github             github                                                                                                                                               https://github.com/enterprise                                                                                                                                 github.com\enterprise             github.com  https://github.com/hansalemaos/getevent_sendevent
55     https                     cli.github.com                                                                                                                                                                                                                                                           False                                                                                                                                        https://cli.github.com                                                                                                                                        https://cli.github.com        .com                     cli.github             github           cli                                                                                                                                        https://cli.github.com                                                                                                                                        cli.github.com             github.com  https://github.com/hansalemaos/getevent_sendevent
56     https                         github.com                                                                                                                                                     sending-touchswipe-events-to-bluestacksandroid-sounds-easy-but-actually-it-isnt                        True                             https://github.com/hansalemaos/getevent_sendevent#sending-touchswipe-events-to-bluestacksandroid-sounds-easy-but-actually-it-isnt                                                            https://github.com#sending-touchswipe-events-to-bluestacksandroid-sounds-easy-but-actually-it-isnt        .com                         github             github                                           https://github.com/hansalemaos/getevent_sendevent#sending-touchswipe-events-to-bluestacksandroid-sounds-easy-but-actually-it-isnt                             github.com\hansalemaos\getevent_sendevent#sending-touchswipe-events-to-bluestacksandroid-sounds-easy-but-actually-it-isnt             github.com  https://github.com/hansalemaos/getevent_sendevent
57     https                         github.com                                                                                                          /features/discussions                                                                                                                             True                                                                                                                       https://github.com/features/discussions                                                                                                                       https://github.com/features/discussions        .com                         github             github                                                                                                                                     https://github.com/features/discussions                                                                                                                       github.com\features\discussions             github.com  https://github.com/hansalemaos/getevent_sendevent
58     https                         github.com                                                                                       /hansalemaos/getevent_sendevent/watchers                                                                                                                             True                                                                                                    https://github.com/hansalemaos/getevent_sendevent/watchers                                                                                                    https://github.com/hansalemaos/getevent_sendevent/watchers        .com                         github             github                                                                                                                  https://github.com/hansalemaos/getevent_sendevent/watchers                                                                                                    github.com\hansalemaos\getevent_sendevent\watchers             github.com  https://github.com/hansalemaos/getevent_sendevent
59     https                         github.com                                                            /hansalemaos/getevent_sendevent/hovercards/citation/sidebar_partial      tree_name=main                                                                                                         True                                                                         https://github.com/hansalemaos/getevent_sendevent/hovercards/citation/sidebar_partial                                                          https://github.com/hansalemaos/getevent_sendevent/hovercards/citation/sidebar_partial?tree_name=main        .com                         github             github                                                                                       https://github.com/hansalemaos/getevent_sendevent/hovercards/citation/sidebar_partial                                                                         github.com\hansalemaos\getevent_sendevent\hovercards\citation\sidebar_partial             github.com  https://github.com/hansalemaos/getevent_sendevent
60     https                 support.github.com                                                                                                                                 tags=dotcom-footer                                                                                                        False                                                                                                                                    https://support.github.com                                                                                                                 https://support.github.com?tags=dotcom-footer        .com                 support.github             github       support                                                                                                                                    https://support.github.com                                                                                                                                    support.github.com             github.com  https://github.com/hansalemaos/getevent_sendevent
61     https                         github.com                                                                                                                                                                                                                             3rd-way                        True                                                                                                     https://github.com/hansalemaos/getevent_sendevent#3rd-way                                                                                                                                    https://github.com#3rd-way        .com                         github             github                                                                                                                   https://github.com/hansalemaos/getevent_sendevent#3rd-way                                                                                                     github.com\hansalemaos\getevent_sendevent#3rd-way             github.com  https://github.com/hansalemaos/getevent_sendevent
62     https                         github.com                                                /hansalemaos/getevent_sendevent/commit/7b2008e5315e79646e0257530ad0e6ee15e30db2                                                                                                                             True                                                             https://github.com/hansalemaos/getevent_sendevent/commit/7b2008e5315e79646e0257530ad0e6ee15e30db2                                                             https://github.com/hansalemaos/getevent_sendevent/commit/7b2008e5315e79646e0257530ad0e6ee15e30db2        .com                         github             github                                                                           https://github.com/hansalemaos/getevent_sendevent/commit/7b2008e5315e79646e0257530ad0e6ee15e30db2                                                             github.com\hansalemaos\getevent_sendevent\commit\7b2008e5315e79646e0257530ad0e6ee15e30db2             github.com  https://github.com/hansalemaos/getevent_sendevent
63     https            github.githubassets.com                                                                                      /assets/topic-suggestions-1f8130174d43.js                                                                                                              .js           False                                                                                      https://github.githubassets.com/assets/topic-suggestions-1f8130174d43.js                                                                                      https://github.githubassets.com/assets/topic-suggestions-1f8130174d43.js        .com            github.githubassets       githubassets        github                                                                                      https://github.githubassets.com/assets/topic-suggestions-1f8130174d43.js                                                                                      github.githubassets.com\assets\topic-suggestions-1f8130174d43.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
64     https                         github.com                                                                                            /hansalemaos/getevent_sendevent.git                                                                                                             .git           False                                                                                                         https://github.com/hansalemaos/getevent_sendevent.git                                                                                                         https://github.com/hansalemaos/getevent_sendevent.git        .com                         github             github                                                                                                                       https://github.com/hansalemaos/getevent_sendevent.git                                                                                                         github.com\hansalemaos\getevent_sendevent.git             github.com  https://github.com/hansalemaos/getevent_sendevent
65     https                         github.com                                                                                                          /features/code-review                                                                                                                             True                                                                                                                       https://github.com/features/code-review                                                                                                                       https://github.com/features/code-review        .com                         github             github                                                                                                                                     https://github.com/features/code-review                                                                                                                       github.com\features\code-review             github.com  https://github.com/hansalemaos/getevent_sendevent
66     https                    www.youtube.com                                                                                                                         /watch       v=BNDtruH6frI                                                                                                        False                                                                                                                                 https://www.youtube.com/watch                                                                                                                   https://www.youtube.com/watch?v=BNDtruH6frI        .com                        youtube            youtube                                                                                                                                               https://www.youtube.com/watch                                                                                                                                 www.youtube.com\watch            youtube.com  https://github.com/hansalemaos/getevent_sendevent
67     https            github.githubassets.com                                                         /assets/app_assets_modules_github_updatable-content_ts-62df1309213c.js                                                                                                              .js           False                                                         https://github.githubassets.com/assets/app_assets_modules_github_updatable-content_ts-62df1309213c.js                                                         https://github.githubassets.com/assets/app_assets_modules_github_updatable-content_ts-62df1309213c.js        .com            github.githubassets       githubassets        github                                                         https://github.githubassets.com/assets/app_assets_modules_github_updatable-content_ts-62df1309213c.js                                                         github.githubassets.com\assets\app_assets_modules_github_updatable-content_ts-62df1309213c.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
68     https            github.githubassets.com                                                                                            /assets/environment-28efc4e97933.js                                                                                                              .js           False                                                                                            https://github.githubassets.com/assets/environment-28efc4e97933.js                                                                                            https://github.githubassets.com/assets/environment-28efc4e97933.js        .com            github.githubassets       githubassets        github                                                                                            https://github.githubassets.com/assets/environment-28efc4e97933.js                                                                                            github.githubassets.com\assets\environment-28efc4e97933.js       githubassets.com  https://github.com/hansalemaos/getevent_sendevent
69     https                  skills.github.com                                                                                                                              /                                                                                                                            False                                                                                                                                    https://skills.github.com/                                                                                                                                    https://skills.github.com/        .com                  skills.github             github        skills                                                                                                                                    https://skills.github.com/                                                                                                                                     skills.github.com             github.com  https://github.com/hansalemaos/getevent_sendevent
...
"""

allurls = [
    """https://gist.github.com/""",
    """https://pypi.org/project/window2video/""",
    """https://github.dev/""",
    """https://docs.github.com/articles/which-remote-url-should-i-use""",
    """https://cli.github.com/""",
    """x-github-client://openRepo/https://github.com/hansalemaos/window2video""",
    """https://desktop.github.com/""",
    """https://developer.apple.com/xcode/""",
    """/window2video/main/LICENSE""",
    """/window2video/main/README.MD""",
    """/window2video/main/__init__.py""",
    """/window2video/main/requirements.txt""",
    """/window2video/main/thirdparty.json""",
    """https://docs.github.com/en/github/site-policy/github-terms-of-service""",
    """https://docs.github.com/en/github/site-policy/github-privacy-statement""",
    """https://www.githubstatus.com/""",
    """https://docs.github.com/""",
    """https://support.github.com/?tags=dotcom-footer""",
    """https://services.github.com/""",
    """https://github.blog/""",
]
df2 = get_url_df(
    urls=allurls,
    join_relative_link_with="https://raw.githubusercontent.com/hansalemaos/",
)

r"""
print(df2.to_string())
          aa_scheme                  aa_netloc                                          aa_path            aa_query aa_fragment aa_filetype  aa_is_relative                                                          aa_url_noquery                                                            aa_url_query aa_toplevel    aa_subdomain_domain          aa_domain aa_subdomains                                                     aa_unquoted_noquery                                                aa_folder_on_hdd         aa_domain_w_tl                                     aa_original
0             https            gist.github.com                                                /                                                       False                                                https://gist.github.com/                                                https://gist.github.com/        .com            gist.github             github          gist                                                https://gist.github.com/                                                 gist.github.com             github.com  https://raw.githubusercontent.com/hansalemaos/
1             https                   pypi.org                           /project/window2video/                                                       False                                  https://pypi.org/project/window2video/                                  https://pypi.org/project/window2video/        .org                   pypi               pypi                                                https://pypi.org/project/window2video/                                   pypi.org\project\window2video               pypi.org  https://raw.githubusercontent.com/hansalemaos/
2             https                 github.dev                                                /                                                       False                                                     https://github.dev/                                                     https://github.dev/        .dev                 github             github                                                                   https://github.dev/                                                      github.dev             github.dev  https://raw.githubusercontent.com/hansalemaos/
3             https            docs.github.com          /articles/which-remote-url-should-i-use                                                       False          https://docs.github.com/articles/which-remote-url-should-i-use          https://docs.github.com/articles/which-remote-url-should-i-use        .com            docs.github             github          docs          https://docs.github.com/articles/which-remote-url-should-i-use          docs.github.com\articles\which-remote-url-should-i-use             github.com  https://raw.githubusercontent.com/hansalemaos/
4             https             cli.github.com                                                /                                                       False                                                 https://cli.github.com/                                                 https://cli.github.com/        .com             cli.github             github           cli                                                 https://cli.github.com/                                                  cli.github.com             github.com  https://raw.githubusercontent.com/hansalemaos/
5   x-github-client                   openRepo     /https://github.com/hansalemaos/window2video                                                       False  x-github-client://openRepo/https://github.com/hansalemaos/window2video  x-github-client://openRepo/https://github.com/hansalemaos/window2video                                                                      x-github-client://openRepo/https://github.com/hansalemaos/window2video             openRepo\https_\github.com\hansalemaos\window2video                         https://raw.githubusercontent.com/hansalemaos/
6             https         desktop.github.com                                                /                                                       False                                             https://desktop.github.com/                                             https://desktop.github.com/        .com         desktop.github             github       desktop                                             https://desktop.github.com/                                              desktop.github.com             github.com  https://raw.githubusercontent.com/hansalemaos/
7             https        developer.apple.com                                          /xcode/                                                       False                                      https://developer.apple.com/xcode/                                      https://developer.apple.com/xcode/        .com        developer.apple              apple     developer                                      https://developer.apple.com/xcode/                                       developer.apple.com\xcode              apple.com  https://raw.githubusercontent.com/hansalemaos/
8             https  raw.githubusercontent.com                       /window2video/main/LICENSE                                                        True             https://raw.githubusercontent.com/window2video/main/LICENSE             https://raw.githubusercontent.com/window2video/main/LICENSE        .com  raw.githubusercontent  githubusercontent           raw             https://raw.githubusercontent.com/window2video/main/LICENSE             raw.githubusercontent.com\window2video\main\LICENSE  githubusercontent.com  https://raw.githubusercontent.com/hansalemaos/
9             https  raw.githubusercontent.com                     /window2video/main/README.MD                                         .MD            True           https://raw.githubusercontent.com/window2video/main/README.MD           https://raw.githubusercontent.com/window2video/main/README.MD        .com  raw.githubusercontent  githubusercontent           raw           https://raw.githubusercontent.com/window2video/main/README.MD           raw.githubusercontent.com\window2video\main\README.MD  githubusercontent.com  https://raw.githubusercontent.com/hansalemaos/
10            https  raw.githubusercontent.com                   /window2video/main/__init__.py                                         .py            True         https://raw.githubusercontent.com/window2video/main/__init__.py         https://raw.githubusercontent.com/window2video/main/__init__.py        .com  raw.githubusercontent  githubusercontent           raw         https://raw.githubusercontent.com/window2video/main/__init__.py           raw.githubusercontent.com\window2video\main\_init_.py  githubusercontent.com  https://raw.githubusercontent.com/hansalemaos/
11            https  raw.githubusercontent.com              /window2video/main/requirements.txt                                        .txt            True    https://raw.githubusercontent.com/window2video/main/requirements.txt    https://raw.githubusercontent.com/window2video/main/requirements.txt        .com  raw.githubusercontent  githubusercontent           raw    https://raw.githubusercontent.com/window2video/main/requirements.txt    raw.githubusercontent.com\window2video\main\requirements.txt  githubusercontent.com  https://raw.githubusercontent.com/hansalemaos/
12            https  raw.githubusercontent.com               /window2video/main/thirdparty.json                                       .json            True     https://raw.githubusercontent.com/window2video/main/thirdparty.json     https://raw.githubusercontent.com/window2video/main/thirdparty.json        .com  raw.githubusercontent  githubusercontent           raw     https://raw.githubusercontent.com/window2video/main/thirdparty.json     raw.githubusercontent.com\window2video\main\thirdparty.json  githubusercontent.com  https://raw.githubusercontent.com/hansalemaos/
13            https            docs.github.com   /en/github/site-policy/github-terms-of-service                                                       False   https://docs.github.com/en/github/site-policy/github-terms-of-service   https://docs.github.com/en/github/site-policy/github-terms-of-service        .com            docs.github             github          docs   https://docs.github.com/en/github/site-policy/github-terms-of-service   docs.github.com\en\github\site-policy\github-terms-of-service             github.com  https://raw.githubusercontent.com/hansalemaos/
14            https            docs.github.com  /en/github/site-policy/github-privacy-statement                                                       False  https://docs.github.com/en/github/site-policy/github-privacy-statement  https://docs.github.com/en/github/site-policy/github-privacy-statement        .com            docs.github             github          docs  https://docs.github.com/en/github/site-policy/github-privacy-statement  docs.github.com\en\github\site-policy\github-privacy-statement             github.com  https://raw.githubusercontent.com/hansalemaos/
15            https       www.githubstatus.com                                                /                                                       False                                           https://www.githubstatus.com/                                           https://www.githubstatus.com/        .com           githubstatus       githubstatus                                                         https://www.githubstatus.com/                                            www.githubstatus.com       githubstatus.com  https://raw.githubusercontent.com/hansalemaos/
16            https            docs.github.com                                                /                                                       False                                                https://docs.github.com/                                                https://docs.github.com/        .com            docs.github             github          docs                                                https://docs.github.com/                                                 docs.github.com             github.com  https://raw.githubusercontent.com/hansalemaos/
17            https         support.github.com                                                /  tags=dotcom-footer                                   False                                             https://support.github.com/                          https://support.github.com/?tags=dotcom-footer        .com         support.github             github       support                                             https://support.github.com/                                              support.github.com             github.com  https://raw.githubusercontent.com/hansalemaos/
18            https        services.github.com                                                /                                                       False                                            https://services.github.com/                                            https://services.github.com/        .com        services.github             github      services                                            https://services.github.com/                                             services.github.com             github.com  https://raw.githubusercontent.com/hansalemaos/
19            https                github.blog                                                /                                                       False                                                    https://github.blog/                                                    https://github.blog/       .blog                 github             github                                                                  https://github.blog/                                                     github.blog            github.blog  https://raw.githubusercontent.com/hansalemaos/
...
"""
```
